==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/api/llm-config/types.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export enum AuthPlatformStatus {
  ACTIVE = 1,
  AVAILABLE = 2,
  UNAVAILABLE = 3
}

export enum LlmLogo {
  'openai' = 1,
  'dashscope' = 2,
  'qianfan' = 3,
  'deepseek' = 4
}

export type LlmLogoFlag = `${LlmLogo}`

export type AuthPlatformStatusType =
  | AuthPlatformStatus.ACTIVE
  | AuthPlatformStatus.AVAILABLE
  | AuthPlatformStatus.UNAVAILABLE

export interface Platform {
  id: LlmLogoFlag
  name: string
  supportModels: string
}

export interface AuthorizedPlatformDesc {
  platformName: string
  model: string
  desc: string
}

export interface AuthorizedPlatform extends AuthorizedPlatformDesc {
  id: number | string
  platformId: LlmLogoFlag
  name: string
  status: AuthPlatformStatusType
}

export interface PlatformCredential {
  name: string
  displayName: string
}

export interface AuthCredential {
  key: string
  value: string
}

export interface UpdateAuthorizedPlatformConfig extends AuthorizedPlatform {
  authCredentials: AuthCredential[]
  testPassed: boolean
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/api/llm-config/types.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export enum AuthPlatformStatus {
  ACTIVE = 1,
  AVAILABLE = 2,
  UNAVAILABLE = 3
}

export enum LlmLogo {
  'openai' = 1,
  'dashscope' = 2,
  'qianfan' = 3,
  'deepseek' = 4
}

export type AuthPlatformStatusType =
  | AuthPlatformStatus.ACTIVE
  | AuthPlatformStatus.AVAILABLE
  | AuthPlatformStatus.UNAVAILABLE

export interface Platform {
  id: number
  name: string
  supportModels: string
}

export interface AuthorizedPlatformDesc {
  platformName: string
  model: string
  desc: string
}

export interface AuthorizedPlatform extends AuthorizedPlatformDesc {
  id: number
  platformId: number
  name: string
  status: AuthPlatformStatusType
}

export interface PlatformCredential {
  name: string
  displayName: string
}

export interface AuthCredential {
  key: string
  value: string
}

export interface UpdateAuthorizedPlatformConfig extends AuthorizedPlatform {
  authCredentials: AuthCredential[]
  testPassed: boolean
}
